@@ -163,286 +163,293 @@
 #' @importFrom RColorBrewer brewer.pal
 #' @importFrom graphics abline axis legend matplot mtext par points text lines
 memmodel<-function(i.data,
-                    i.seasons=10,
-                    i.type.threshold=5,
-                    i.level.threshold=0.95,
-                    i.tails.threshold=1,
-                    i.type.intensity=6,
-                    i.level.intensity=c(0.40,0.90,0.975),
-                    i.tails.intensity=1,
-                    i.type.curve=2,
-                    i.level.curve=0.95,
-                    i.type.other=3,
-                    i.level.other=0.95,
-                    i.method=2,
-                    i.param=2.8,
-                    i.n.max=-1,
-                    i.type.boot="norm",
-                    i.iter.boot=10000){
+                   i.seasons=10,
+                   i.type.threshold=5,
+                   i.level.threshold=0.95,
+                   i.tails.threshold=1,
+                   i.type.intensity=6,
+                   i.level.intensity=c(0.40,0.90,0.975),
+                   i.tails.intensity=1,
+                   i.type.curve=2,
+                   i.level.curve=0.95,
+                   i.type.other=3,
+                   i.level.other=0.95,
+                   i.method=2,
+                   i.param=2.8,
+                   i.n.max=-1,
+                   i.type.boot="norm",
+                   i.iter.boot=10000){
 
   if (is.null(dim(i.data))) stop('Incorrect number of dimensions, input must be a data.frame.') else if (!(ncol(i.data)>1)) stop('Incorrect number of dimensions, at least two seasons of data required.')
 
   datos<-i.data[apply(i.data,2,function(x) sum(x,na.rm=T)>0)]
 
-  if (is.matrix(datos)) datos<-as.data.frame(datos)
+  if (NCOL(datos)==0){
 
-  if (!is.na(i.seasons)) if (i.seasons>0) datos<-datos[(max((dim(datos)[2])-i.seasons+1,1)):(dim(datos)[2])]
+    memmodel.output <- NULL
 
-  datos<-as.data.frame(apply(datos,2,fill.missing))
-
-  semanas<-dim(datos)[1]
-  anios<-dim(datos)[2]
-
-  # Calcular el optimo
-
-  if (is.na(i.n.max)){
-    n.max<-max(1,round(30/anios,0))
   }else{
-    if (i.n.max==-1){
+    if (is.matrix(datos)) datos<-as.data.frame(datos)
+
+    if (!is.na(i.seasons)) if (i.seasons>0) datos<-datos[(max((dim(datos)[2])-i.seasons+1,1)):(dim(datos)[2])]
+
+    datos<-as.data.frame(apply(datos,2,fill.missing))
+
+    semanas<-dim(datos)[1]
+    anios<-NCOL(datos)
+
+    # Calcular el optimo
+
+    if (is.na(i.n.max)){
       n.max<-max(1,round(30/anios,0))
-      #if (anios>=10) n.max=3 else n.max=5
-    }else if (i.n.max==0){
-      n.max=semanas
     }else{
-      n.max=i.n.max
-    }
-  }
-
-  optimo<-apply(datos,2,memtiming,i.n.values=n.max,i.method=i.method,i.param=i.param)
-
-  datos.duracion.real<-extraer.datos.optimo.map(optimo)
-
-  # por defecto la aritmetica en ambos
-  ic.duracion<-iconfianza(as.numeric(datos.duracion.real[1,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
-  ic.duracion<-rbind(ic.duracion,c(floor(ic.duracion[1]),round(ic.duracion[2]),ceiling(ic.duracion[3])))
-  ic.porcentaje<-iconfianza(as.numeric(datos.duracion.real[2,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
-
-  duracion.media<-ic.duracion[2,2]
-
-  ########################################################################################
-  # Calcula todos los parametros asociados a la temporada gripal en base a la estimacion #
-  # del numero de semanas de duracion total.                                             #
-  ########################################################################################
-
-  # Datos de la gripe en la temporada REAL y en la temporada MEDIA, esta ultima sirve para unir las temporadas.
-
-  semana.inicio<-as.integer(rownames(datos)[1])
-  gripe<-array(dim=c(7,anios,2))
-
-  datos.duracion.media<-extraer.datos.curva.map(optimo,duracion.media)
-
-  for (j in 1:anios){
-    ## Semana en la q comienza la temporada.real
-    gripe[1,j,1]<-datos.duracion.real[4,j]
-    ## Semana en la q acaba
-    gripe[2,j,1]<-datos.duracion.real[5,j]
-    ## numero de casos en la temporada.real de gripe
-    gripe[3,j,1]<-datos.duracion.real[3,j]
-    ## Numero de casos totales de la temporada global
-    gripe[4,j,1]<-sum(datos[,j],na.rm=TRUE)
-    ## Porcentaje cubierto de casos de la temporada gripal
-    gripe[5,j,1]<-datos.duracion.real[2,j]
-    ## Casos Acumulados justo antes de comenzar la temporada gripal
-    if (gripe[1,j,1]>1) gripe[6,j,1]<-sum(datos[1:(gripe[1,j,1]-1),j],na.rm=TRUE) else gripe[6,j,1]<-0
-    ## Casos Despues de la temporada gripal
-    if (gripe[2,j,1]<semanas) gripe[7,j,1]<-sum(datos[(gripe[2,j,1]+1):semanas,j],na.rm=TRUE) else gripe[7,j,1]<-0
-
-    ## Semana en la q comienza la temporada.media
-    gripe[1,j,2]<-datos.duracion.media[4,j]
-    ## Semana en la q acaba
-    gripe[2,j,2]<-datos.duracion.media[5,j]
-    ## numero de casos en la temporada.media de gripe
-    gripe[3,j,2]<-datos.duracion.media[3,j]
-    ## Numero de casos totales de la temporada global
-    gripe[4,j,2]<-sum(datos[,j],na.rm=TRUE)
-    ## Porcentaje cubierto de casos de la temporada gripal
-    gripe[5,j,2]<-datos.duracion.media[2,j]
-    ## Casos Acumulados justo antes de comenzar la temporada gripal
-    if (gripe[1,j,2]>1) gripe[6,j,2]<-sum(datos[1:(gripe[1,j,2]-1),j],na.rm=TRUE) else gripe[6,j,2]<-0
-    ## Casos Despues de la temporada gripal
-    if (gripe[2,j,2]<semanas) gripe[7,j,2]<-sum(datos[(gripe[2,j,2]+1):semanas,j],na.rm=TRUE) else gripe[7,j,2]<-0
-  }
-
-  # Indice de estado temporal. Si es un 1 me dice que estamos en epoca pretemporada,
-  # si pone un 2 indica que estamos en temporada gripal. Si pone un 3 indica que
-  # estamos en posttemporada.
-
-  indices.temporada<-array(dim=c(semanas,anios,2))
-
-  for (j in 1:anios){
-    indices.temporada[-((datos.duracion.real[4,j]):semanas),j,1]<-1
-    indices.temporada[(datos.duracion.real[4,j]):(datos.duracion.real[5,j]),j,1]<-2
-    indices.temporada[-(1:(datos.duracion.real[5,j])),j,1]<-3
-    indices.temporada[-((datos.duracion.media[4,j]):semanas),j,2]<-1
-    indices.temporada[(datos.duracion.media[4,j]):(datos.duracion.media[5,j]),j,2]<-2
-    indices.temporada[-(1:(datos.duracion.media[5,j])),j,2]<-3
-  }
-
-  ## Estimacion del numero de semana en el  comienza la gripe
-
-  ic.inicio<-iconfianza(as.numeric(datos.duracion.real[4,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
-  ic.inicio<-rbind(ic.inicio,c(floor(ic.inicio[1]),round(ic.inicio[2]),ceiling(ic.inicio[3])))
-  ic.inicio<-rbind(ic.inicio,c(semana.absoluta(ic.inicio[2,1],semana.inicio),semana.absoluta(ic.inicio[2,2],semana.inicio),semana.absoluta(ic.inicio[2,3],semana.inicio)))
-  ic.inicio<-ic.inicio[c(2,3,1),]
-  inicio.medio<-ic.inicio[1,2]
-
-  # Grafico del esquema de las temporadas gripales para su union
-
-  longitud.esquema<-semanas+max.fix.na(gripe[1,,2])-min.fix.na(gripe[1,,2])
-  inicio.epidemia.esquema<-max.fix.na(gripe[1,,2])
-  fin.epidemia.esquema<-max.fix.na(gripe[2,,2])
-
-  esquema.temporadas<-array(dim=c(longitud.esquema,anios+2,3))
-
-  for (j in 1:anios){
-    for (i in 1:semanas){
-      diferencia<-inicio.epidemia.esquema-gripe[1,j,2]
-      esquema.temporadas[i+diferencia,j,1]<-i
-      esquema.temporadas[i+diferencia,j,2]<-semana.absoluta(i,semana.inicio)
-      esquema.temporadas[i+diferencia,j,3]<-datos[i,j]
-    }
-  }
-
-  diferencia<-inicio.epidemia.esquema-inicio.medio
-  for (i in 1:semanas){
-    if ((i+diferencia)>=1 & (i+diferencia)<=longitud.esquema){
-      esquema.temporadas[i+diferencia,anios+1,1]<-i
-      esquema.temporadas[i+diferencia,anios+1,2]<-semana.absoluta(i,semana.inicio)
-    }
-  }
-
-  esquema.temporadas[,anios+2,c(1,2)]<-3
-  esquema.temporadas[1:(inicio.epidemia.esquema-1),anios+2,1]<-1
-  esquema.temporadas[(inicio.epidemia.esquema):(inicio.epidemia.esquema+duracion.media-1),anios+2,1]<-2
-  esquema.temporadas[1:(inicio.epidemia.esquema-1),anios+2,2]<-1
-  esquema.temporadas[(inicio.epidemia.esquema):(inicio.epidemia.esquema+duracion.media-1),anios+2,2]<-2
-
-  ## Temporadas moviles
-
-  temporadas.moviles<-esquema.temporadas[,c(1:anios),3]
-
-  ## Limites de la temporada
-
-  limites.temporada<-c(inicio.medio,inicio.medio+duracion.media-1)
-  limites.temporada<-rbind(limites.temporada,c(semana.absoluta(inicio.medio,semana.inicio),semana.absoluta(inicio.medio+duracion.media-1,semana.inicio)))
-
-  # Limites relativos
-
-  limites.esquema<-c(inicio.epidemia.esquema,inicio.epidemia.esquema+duracion.media-1)
-
-  ## En ttotal reordenamos la gripe para q todas las temporadas comiencen la semana "estinicio" (es decir, quitamos informacion
-  ## por delante y por detras de esquema.temporada[,,3] para que queden 35 semanas (las que hay).
-
-  temporadas.moviles.recortada<-array(dim=c(semanas,anios))
-
-  ## Temporada gripal comienza "estinicio" y termina en "estinicio+temporada-1"
-
-  diferencia<-inicio.medio-limites.esquema[1]
-
-  for (j in 1:anios){
-    for (i in 1:semanas){
-      if ((i-diferencia)>=1 & (i-diferencia)<=longitud.esquema){
-        temporadas.moviles.recortada[i,j]<-temporadas.moviles[i-diferencia,j]
+      if (i.n.max==-1){
+        n.max<-max(1,round(30/anios,0))
+        #if (anios>=10) n.max=3 else n.max=5
+      }else if (i.n.max==0){
+        n.max=semanas
       }else{
-        temporadas.moviles.recortada[i,j]<-NA
+        n.max=i.n.max
       }
     }
+
+    optimo<-apply(datos,2,memtiming,i.n.values=n.max,i.method=i.method,i.param=i.param)
+
+    datos.duracion.real<-extraer.datos.optimo.map(optimo)
+
+    # por defecto la aritmetica en ambos
+    ic.duracion<-iconfianza(as.numeric(datos.duracion.real[1,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
+    ic.duracion<-rbind(ic.duracion,c(floor(ic.duracion[1]),round(ic.duracion[2]),ceiling(ic.duracion[3])))
+    ic.porcentaje<-iconfianza(as.numeric(datos.duracion.real[2,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
+
+    duracion.media<-ic.duracion[2,2]
+
+    ########################################################################################
+    # Calcula todos los parametros asociados a la temporada gripal en base a la estimacion #
+    # del numero de semanas de duracion total.                                             #
+    ########################################################################################
+
+    # Datos de la gripe en la temporada REAL y en la temporada MEDIA, esta ultima sirve para unir las temporadas.
+
+    semana.inicio<-as.integer(rownames(datos)[1])
+    gripe<-array(dim=c(7,anios,2))
+
+    datos.duracion.media<-extraer.datos.curva.map(optimo,duracion.media)
+
+    for (j in 1:anios){
+      ## Semana en la q comienza la temporada.real
+      gripe[1,j,1]<-datos.duracion.real[4,j]
+      ## Semana en la q acaba
+      gripe[2,j,1]<-datos.duracion.real[5,j]
+      ## numero de casos en la temporada.real de gripe
+      gripe[3,j,1]<-datos.duracion.real[3,j]
+      ## Numero de casos totales de la temporada global
+      gripe[4,j,1]<-sum(datos[,j],na.rm=TRUE)
+      ## Porcentaje cubierto de casos de la temporada gripal
+      gripe[5,j,1]<-datos.duracion.real[2,j]
+      ## Casos Acumulados justo antes de comenzar la temporada gripal
+      if (gripe[1,j,1]>1) gripe[6,j,1]<-sum(datos[1:(gripe[1,j,1]-1),j],na.rm=TRUE) else gripe[6,j,1]<-0
+      ## Casos Despues de la temporada gripal
+      if (gripe[2,j,1]<semanas) gripe[7,j,1]<-sum(datos[(gripe[2,j,1]+1):semanas,j],na.rm=TRUE) else gripe[7,j,1]<-0
+
+      ## Semana en la q comienza la temporada.media
+      gripe[1,j,2]<-datos.duracion.media[4,j]
+      ## Semana en la q acaba
+      gripe[2,j,2]<-datos.duracion.media[5,j]
+      ## numero de casos en la temporada.media de gripe
+      gripe[3,j,2]<-datos.duracion.media[3,j]
+      ## Numero de casos totales de la temporada global
+      gripe[4,j,2]<-sum(datos[,j],na.rm=TRUE)
+      ## Porcentaje cubierto de casos de la temporada gripal
+      gripe[5,j,2]<-datos.duracion.media[2,j]
+      ## Casos Acumulados justo antes de comenzar la temporada gripal
+      if (gripe[1,j,2]>1) gripe[6,j,2]<-sum(datos[1:(gripe[1,j,2]-1),j],na.rm=TRUE) else gripe[6,j,2]<-0
+      ## Casos Despues de la temporada gripal
+      if (gripe[2,j,2]<semanas) gripe[7,j,2]<-sum(datos[(gripe[2,j,2]+1):semanas,j],na.rm=TRUE) else gripe[7,j,2]<-0
+    }
+
+    # Indice de estado temporal. Si es un 1 me dice que estamos en epoca pretemporada,
+    # si pone un 2 indica que estamos en temporada gripal. Si pone un 3 indica que
+    # estamos en posttemporada.
+
+    indices.temporada<-array(dim=c(semanas,anios,2))
+
+    for (j in 1:anios){
+      indices.temporada[-((datos.duracion.real[4,j]):semanas),j,1]<-1
+      indices.temporada[(datos.duracion.real[4,j]):(datos.duracion.real[5,j]),j,1]<-2
+      indices.temporada[-(1:(datos.duracion.real[5,j])),j,1]<-3
+      indices.temporada[-((datos.duracion.media[4,j]):semanas),j,2]<-1
+      indices.temporada[(datos.duracion.media[4,j]):(datos.duracion.media[5,j]),j,2]<-2
+      indices.temporada[-(1:(datos.duracion.media[5,j])),j,2]<-3
+    }
+
+    ## Estimacion del numero de semana en el  comienza la gripe
+
+    ic.inicio<-iconfianza(as.numeric(datos.duracion.real[4,]),i.level.other,i.type.other,T,i.type.boot,i.iter.boot,2)
+    ic.inicio<-rbind(ic.inicio,c(floor(ic.inicio[1]),round(ic.inicio[2]),ceiling(ic.inicio[3])))
+    ic.inicio<-rbind(ic.inicio,c(semana.absoluta(ic.inicio[2,1],semana.inicio),semana.absoluta(ic.inicio[2,2],semana.inicio),semana.absoluta(ic.inicio[2,3],semana.inicio)))
+    ic.inicio<-ic.inicio[c(2,3,1),]
+    inicio.medio<-ic.inicio[1,2]
+
+    # Grafico del esquema de las temporadas gripales para su union
+
+    longitud.esquema<-semanas+max.fix.na(gripe[1,,2])-min.fix.na(gripe[1,,2])
+    inicio.epidemia.esquema<-max.fix.na(gripe[1,,2])
+    fin.epidemia.esquema<-max.fix.na(gripe[2,,2])
+
+    esquema.temporadas<-array(dim=c(longitud.esquema,anios+2,3))
+
+    for (j in 1:anios){
+      for (i in 1:semanas){
+        diferencia<-inicio.epidemia.esquema-gripe[1,j,2]
+        esquema.temporadas[i+diferencia,j,1]<-i
+        esquema.temporadas[i+diferencia,j,2]<-semana.absoluta(i,semana.inicio)
+        esquema.temporadas[i+diferencia,j,3]<-datos[i,j]
+      }
+    }
+
+    diferencia<-inicio.epidemia.esquema-inicio.medio
+    for (i in 1:semanas){
+      if ((i+diferencia)>=1 & (i+diferencia)<=longitud.esquema){
+        esquema.temporadas[i+diferencia,anios+1,1]<-i
+        esquema.temporadas[i+diferencia,anios+1,2]<-semana.absoluta(i,semana.inicio)
+      }
+    }
+
+    esquema.temporadas[,anios+2,c(1,2)]<-3
+    esquema.temporadas[1:(inicio.epidemia.esquema-1),anios+2,1]<-1
+    esquema.temporadas[(inicio.epidemia.esquema):(inicio.epidemia.esquema+duracion.media-1),anios+2,1]<-2
+    esquema.temporadas[1:(inicio.epidemia.esquema-1),anios+2,2]<-1
+    esquema.temporadas[(inicio.epidemia.esquema):(inicio.epidemia.esquema+duracion.media-1),anios+2,2]<-2
+
+    ## Temporadas moviles
+
+    temporadas.moviles<-esquema.temporadas[,c(1:anios),3]
+
+    ## Limites de la temporada
+
+    limites.temporada<-c(inicio.medio,inicio.medio+duracion.media-1)
+    limites.temporada<-rbind(limites.temporada,c(semana.absoluta(inicio.medio,semana.inicio),semana.absoluta(inicio.medio+duracion.media-1,semana.inicio)))
+
+    # Limites relativos
+
+    limites.esquema<-c(inicio.epidemia.esquema,inicio.epidemia.esquema+duracion.media-1)
+
+    ## En ttotal reordenamos la gripe para q todas las temporadas comiencen la semana "estinicio" (es decir, quitamos informacion
+    ## por delante y por detras de esquema.temporada[,,3] para que queden 35 semanas (las que hay).
+
+    temporadas.moviles.recortada<-array(dim=c(semanas,anios))
+
+    ## Temporada gripal comienza "estinicio" y termina en "estinicio+temporada-1"
+
+    diferencia<-inicio.medio-limites.esquema[1]
+
+    for (j in 1:anios){
+      for (i in 1:semanas){
+        if ((i-diferencia)>=1 & (i-diferencia)<=longitud.esquema){
+          temporadas.moviles.recortada[i,j]<-temporadas.moviles[i-diferencia,j]
+        }else{
+          temporadas.moviles.recortada[i,j]<-NA
+        }
+      }
+    }
+
+    ## Dibujamos la curva epidemica tipo
+
+    # Importante: ?Quitamos los ceros?
+    # iy<-(is.na(temporadas.moviles.recortada) | temporadas.moviles.recortada==0)
+    iy<-is.na(temporadas.moviles.recortada)
+    temporadas.moviles.recortada.no.ceros<-temporadas.moviles.recortada
+    temporadas.moviles.recortada.no.ceros[iy]<-NA
+    curva.tipo<-t(apply(temporadas.moviles.recortada.no.ceros,1,iconfianza,nivel=i.level.curve,tipo=i.type.curve,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=2))
+
+    ## Seleccionamos los periodos pre, epidemia, y post
+
+    ## PRE y POST-TEMPORADA GRIPAL
+
+    ## Como no se registra mas q de la semana 40 a la 20, tenemos q muchas de las semanas tienen tasa 0, eliminamos esas semanas,
+    ## ya q podrian llevar a una infraestimacion de la tasa base fuera de temporada
+
+    pre.datos<-as.vector(as.matrix(extraer.datos.pre.epi(optimo)))
+    post.datos<-as.vector(as.matrix(extraer.datos.post.epi(optimo)))
+    epi.datos<-as.vector(as.matrix(extraer.datos.epi(optimo)))
+    epi.datos.2<-as.vector(as.matrix(apply(datos,2,max.n.valores,n.max=n.max)))
+
+    pre.post.datos<-rbind(pre.datos,post.datos)
+
+    # IC de la linea basica de pre y post temporada
+
+    # por defecto estaba la geometrica
+    # pre.d<-pre.datos[!(is.na(pre.datos) | pre.datos==0)]
+    # post.d<-post.datos[!(is.na(post.datos) | post.datos==0)]
+    # epi.d<-epi.datos[!(is.na(epi.datos) | epi.datos==0)]
+    # epi.d.2<-epi.datos.2[!(is.na(epi.datos.2) | epi.datos.2==0)]
+    pre.d<-pre.datos[!is.na(pre.datos)]
+    post.d<-post.datos[!is.na(post.datos)]
+    epi.d<-epi.datos[!is.na(epi.datos)]
+    epi.d.2<-epi.datos.2[!is.na(epi.datos.2)]
+
+    pre.i<-iconfianza(pre.d,nivel=i.level.threshold,tipo=i.type.threshold,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=i.tails.threshold)
+    post.i<-iconfianza(post.d,nivel=i.level.threshold,tipo=i.type.threshold,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=i.tails.threshold)
+    epi.intervalos<-numeric()
+    for (niv in i.level.intensity) epi.intervalos<-rbind(epi.intervalos,c(niv,iconfianza(epi.d,nivel=niv,tipo=i.type.intensity,ic=T,colas=i.tails.intensity)))
+    epi.intervalos.2<-numeric()
+    for (niv in i.level.intensity) epi.intervalos.2<-rbind(epi.intervalos.2,c(niv,iconfianza(epi.d.2,nivel=niv,tipo=i.type.intensity,ic=T,colas=i.tails.intensity)))
+
+    pre.post.intervalos<-rbind(pre.i,post.i)
+
+    memmodel.output<-list(pre.post.intervals=pre.post.intervalos,
+                          ci.length=ic.duracion,
+                          ci.percent=ic.porcentaje,
+                          ci.start=ic.inicio,
+                          mean.length=duracion.media,
+                          mean.start=inicio.medio,
+                          moving.epidemics=temporadas.moviles.recortada,
+                          epi.intervals=epi.intervalos,
+                          epi.intervals.full=epi.intervalos.2,
+                          typ.curve=curva.tipo,
+                          n.max=n.max,
+                          n.seasons=anios,
+                          n.weeks=semanas,
+                          data=datos,
+                          start.week=semana.inicio,
+                          epi.data=epi.datos,
+                          epi.data.nona=epi.d,
+                          epi.data.full=epi.datos.2,
+                          epi.data.nona.full=epi.d.2,
+                          optimum=optimo,
+                          real.length.data=datos.duracion.real,
+                          seasons.data=gripe,
+                          season.indexes=indices.temporada,
+                          season.scheme=esquema.temporadas,
+                          seasons.moving=temporadas.moviles,
+                          pre.post.data=pre.post.datos,
+                          pre.data.nona=pre.d,
+                          post.data.nona=post.d,
+                          epidemic.thresholds=as.numeric(pre.post.intervalos[,3]),
+                          intensity.thresholds=as.numeric(epi.intervalos[,4]),
+                          param.data=i.data,
+                          param.seasons=i.seasons,
+                          param.type.threshold=i.type.threshold,
+                          param.level.threshold=i.level.threshold,
+                          param.tails.threshold=i.tails.threshold,
+                          param.type.intensity=i.type.intensity,
+                          param.level.intensity=i.level.intensity,
+                          param.tails.intensity=i.tails.intensity,
+                          param.type.curve=i.type.curve,
+                          param.level.curve=i.level.curve,
+                          param.type.other=i.type.other,
+                          param.level.other=i.level.other,
+                          param.method=i.method,
+                          param.param=i.param,
+                          param.n.max=i.n.max,
+                          param.type.boot=i.type.boot,
+                          param.iter.boot=i.iter.boot)
+
+    memmodel.output$call<-match.call()
+    class(memmodel.output)<-"mem"
   }
 
-  ## Dibujamos la curva epidemica tipo
-
-  # Importante: ?Quitamos los ceros?
-  # iy<-(is.na(temporadas.moviles.recortada) | temporadas.moviles.recortada==0)
-  iy<-is.na(temporadas.moviles.recortada)
-  temporadas.moviles.recortada.no.ceros<-temporadas.moviles.recortada
-  temporadas.moviles.recortada.no.ceros[iy]<-NA
-  curva.tipo<-t(apply(temporadas.moviles.recortada.no.ceros,1,iconfianza,nivel=i.level.curve,tipo=i.type.curve,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=2))
-
-  ## Seleccionamos los periodos pre, epidemia, y post
-
-  ## PRE y POST-TEMPORADA GRIPAL
-
-  ## Como no se registra mas q de la semana 40 a la 20, tenemos q muchas de las semanas tienen tasa 0, eliminamos esas semanas,
-  ## ya q podrian llevar a una infraestimacion de la tasa base fuera de temporada
-
-  pre.datos<-as.vector(as.matrix(extraer.datos.pre.epi(optimo)))
-  post.datos<-as.vector(as.matrix(extraer.datos.post.epi(optimo)))
-  epi.datos<-as.vector(as.matrix(extraer.datos.epi(optimo)))
-  epi.datos.2<-as.vector(as.matrix(apply(datos,2,max.n.valores,n.max=n.max)))
-
-  pre.post.datos<-rbind(pre.datos,post.datos)
-
-  # IC de la linea basica de pre y post temporada
-
-  # por defecto estaba la geometrica
-  # pre.d<-pre.datos[!(is.na(pre.datos) | pre.datos==0)]
-  # post.d<-post.datos[!(is.na(post.datos) | post.datos==0)]
-  # epi.d<-epi.datos[!(is.na(epi.datos) | epi.datos==0)]
-  # epi.d.2<-epi.datos.2[!(is.na(epi.datos.2) | epi.datos.2==0)]
-  pre.d<-pre.datos[!is.na(pre.datos)]
-  post.d<-post.datos[!is.na(post.datos)]
-  epi.d<-epi.datos[!is.na(epi.datos)]
-  epi.d.2<-epi.datos.2[!is.na(epi.datos.2)]
-
-  pre.i<-iconfianza(pre.d,nivel=i.level.threshold,tipo=i.type.threshold,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=i.tails.threshold)
-  post.i<-iconfianza(post.d,nivel=i.level.threshold,tipo=i.type.threshold,ic=T,tipo.boot=i.type.boot,iteraciones.boot=i.iter.boot,colas=i.tails.threshold)
-  epi.intervalos<-numeric()
-  for (niv in i.level.intensity) epi.intervalos<-rbind(epi.intervalos,c(niv,iconfianza(epi.d,nivel=niv,tipo=i.type.intensity,ic=T,colas=i.tails.intensity)))
-  epi.intervalos.2<-numeric()
-  for (niv in i.level.intensity) epi.intervalos.2<-rbind(epi.intervalos.2,c(niv,iconfianza(epi.d.2,nivel=niv,tipo=i.type.intensity,ic=T,colas=i.tails.intensity)))
-
-  pre.post.intervalos<-rbind(pre.i,post.i)
-
-  memmodel.output<-list(pre.post.intervals=pre.post.intervalos,
-    ci.length=ic.duracion,
-    ci.percent=ic.porcentaje,
-    ci.start=ic.inicio,
-    mean.length=duracion.media,
-    mean.start=inicio.medio,
-    moving.epidemics=temporadas.moviles.recortada,
-    epi.intervals=epi.intervalos,
-    epi.intervals.full=epi.intervalos.2,
-    typ.curve=curva.tipo,
-    n.max=n.max,
-    n.seasons=anios,
-    n.weeks=semanas,
-    data=datos,
-    start.week=semana.inicio,
-    epi.data=epi.datos,
-    epi.data.nona=epi.d,
-    epi.data.full=epi.datos.2,
-    epi.data.nona.full=epi.d.2,
-    optimum=optimo,
-    real.length.data=datos.duracion.real,
-    seasons.data=gripe,
-    season.indexes=indices.temporada,
-    season.scheme=esquema.temporadas,
-    seasons.moving=temporadas.moviles,
-    pre.post.data=pre.post.datos,
-    pre.data.nona=pre.d,
-    post.data.nona=post.d,
-    epidemic.thresholds=as.numeric(pre.post.intervalos[,3]),
-    intensity.thresholds=as.numeric(epi.intervalos[,4]),
-    param.data=i.data,
-    param.seasons=i.seasons,
-    param.type.threshold=i.type.threshold,
-    param.level.threshold=i.level.threshold,
-    param.tails.threshold=i.tails.threshold,
-    param.type.intensity=i.type.intensity,
-    param.level.intensity=i.level.intensity,
-    param.tails.intensity=i.tails.intensity,
-    param.type.curve=i.type.curve,
-    param.level.curve=i.level.curve,
-    param.type.other=i.type.other,
-    param.level.other=i.level.other,
-    param.method=i.method,
-    param.param=i.param,
-    param.n.max=i.n.max,
-    param.type.boot=i.type.boot,
-    param.iter.boot=i.iter.boot)
-
-  memmodel.output$call<-match.call()
-  class(memmodel.output)<-"mem"
   return(memmodel.output)
 }
 
