@@ -50,6 +50,7 @@
 #' @export
 #' @importFrom stats aggregate
 #' @importFrom reshape2 melt
+#' @importFrom stringr str_match
 transformdata.back<-function(i.data, i.name="rates", i.cutoff.original=NA, i.range.x.final=NA, i.fun=sum){
   if (is.na(i.cutoff.original)) i.cutoff.original<-min(as.numeric(rownames(i.data)[1:(min(3,NROW(i.data)))]))
   if (i.cutoff.original < 1) i.cutoff.original <- 1
@@ -64,9 +65,9 @@ transformdata.back<-function(i.data, i.name="rates", i.cutoff.original=NA, i.ran
   n.seasons<-NCOL(i.data)
   # First: analize names of seasons and seasons with week 53
   if (n.seasons>1){
-    seasons<-data.frame(names(i.data),matrix(str_match(names(i.data),"(\\d{4})(?:.*(\\d{4}))?(?:.*\\(.*(\\d{1,}).*\\))?"),nrow=n.seasons,byrow=F)[,-1],stringsAsFactors = F)
+    seasons<-data.frame(names(i.data),matrix(stringr:: str_match(names(i.data),"(\\d{4})(?:.*(\\d{4}))?(?:.*\\(.*(\\d{1,}).*\\))?"),nrow=n.seasons,byrow=F)[,-1],stringsAsFactors = F)
   }else{
-    seasons<-data.frame(t(c(names(i.data),str_match(names(i.data),"(\\d{4})(?:.*(\\d{4}))?(?:.*\\(.*(\\d{1,}).*\\))?")[-1])),stringsAsFactors = F)
+    seasons<-data.frame(t(c(names(i.data),stringr:: str_match(names(i.data),"(\\d{4})(?:.*(\\d{4}))?(?:.*\\(.*(\\d{1,}).*\\))?")[-1])),stringsAsFactors = F)
   }
   names(seasons)<-c("column","anioi","aniof","aniow")
   seasons[is.na(seasons)]<-""
@@ -79,7 +80,7 @@ transformdata.back<-function(i.data, i.name="rates", i.cutoff.original=NA, i.ran
   names(i.data)<-seasons$season
   i.data$week<-as.numeric(row.names(i.data))
   # Second: Transform the data, summarize (to avoid duplicates) and remove na's
-  data.out<-melt(i.data, "week", variable="season", value.name = "data", na.rm = T)
+  data.out<-reshape2::melt(i.data, "week", variable="season", value.name = "data", na.rm = T)
   # adds year, based in the i.cutoff.original value
   data.out$year<-NA
   data.out$year[data.out$week<i.cutoff.original]<-as.numeric(substr(data.out$season,6,9))[data.out$week<i.cutoff.original]
